Learn R Programming

htmlTable (version 2.1.0)

getHtmlTableTheme: Retrieve the htmlTable() theme list

Description

A wrapper for a getOption("htmlTable.theme")() call that returns the standard theme unless one is set.

Usage

getHtmlTableTheme()

Arguments

Value

list with the styles to be applied to the table

Examples

Run this code
# NOT RUN {
getHtmlTableTheme()
# }

Run the code above in your browser using DataLab