powered by
htmlTable()
A wrapper for a getOption("htmlTable.theme")() call that returns the standard theme unless one is set.
getOption("htmlTable.theme")()
getHtmlTableTheme()
list with the styles to be applied to the table
list
# NOT RUN { getHtmlTableTheme() # }
Run the code above in your browser using DataLab